@@ -1,4 +1,4 @@
-skip_if_not_or_load_if_installed("lme4")
+skip_if_not_installed("lme4")
 
 test_that("report-lmer", {
   df <- lme4::sleepstudy
